#ifndef KYLINCAMERA_H
#define KYLINCAMERA_H

#include <QObject>
#include <QtMultimedia/QAudioInput>
#include "kylincamera_global.h"
#include <linux/videodev2.h>

class VideoDisplay;

enum CameraOptions {
    CAMERA_NONE = 0,
    CAMERA_CAPTURE,
    CAMERA_DECODE,
    CAMERA_ENCODE
};

enum CameraState {
    CAMERA_STATE_NONE = 0,
    CAMERA_CAPTURE_READ,
    CAMERA_CAPTURE_READ_ERR,
    CAMERA_ENCODE_START,
    CAMERA_ENCODE_STOP
};

class KylinCamera : public QObject
{
    Q_OBJECT
public:
    explicit KylinCamera(QObject *parent = nullptr);
    ~KylinCamera();

    V4l2DeviceInfo device_info;

    VideoDisplay *create(QWidget *parent, KylinCameraInfo *device);
    static int enum_device(V4l2DeviceInfo *device);
    static int fourcc(unsigned int format);

    void camera_capture_pause();
    void camera_capture_restore();
    int camera_set_param(KylinCameraInfo *device);
    int camera_get_param(KylinCameraInfo *device);
    int camera_get_mode();
    int camera_take_photo(char *photopath);
    int camera_start_record(char *videopath, bool hwenc=false);
    int camera_stop_record();
    int camera_record_pause(bool on);
//    int camera_video_enable(bool enable);

    int camera_audio_init(const QAudioDeviceInfo &deviceInfo);
    int camera_audio_disable();

	enum CameraState camera_get_state(enum CameraOptions opt);
    void camera_display_mirror(bool on);
    void camera_record_mirror(bool on);

signals:

private:
    VideoDisplay *videoWiget;

    static int enum_frame_intervals(int fd, TypePixFormats *pixfmt, TypeFramesizes *fsize);
    static int enum_frame_sizes(int fd, TypePixFormats *pixfmt);
    unsigned long m_rate;           //sample rate
    unsigned int m_channels;	       //audio channels
    unsigned long m_bit_size;           //sample bit size
};

#endif // KYLINCAMERA_H
